Enum lzw::Bits [−][src]
Containes either the consumed bytes and reconstructed bits or only the consumed bytes if the supplied buffer was not bit enough
Variants
Consumed bytes, reconstructed bits
None(usize)Consumed bytes